==> elasticsearch-java-7.15.0-sources.jar: co/elastic/clients/elasticsearch/security/IndexPrivilege.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.security;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.util.StringEnum;

@JsonpDeserializable
public enum IndexPrivilege implements StringEnum {
	All("all"), AutoConfigure("auto_configure"), Create("create"), CreateDoc("create_doc"), CreateIndex(
			"create_index"), Delete("delete"), DeleteIndex("delete_index"), Index("index"), Maintenance(
					"maintenance"), Manage("manage"), ManageFollowIndex("manage_follow_index"), ManageIlm(
							"manage_ilm"), ManageLeaderIndex("manage_leader_index"), Monitor("monitor"), Read(
									"read"), ReadCrossCluster("read_cross_cluster"), ViewIndexMetadata(
											"view_index_metadata"), Write("write");

	private final String jsonValue;

	IndexPrivilege(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final StringEnum.Deserializer<IndexPrivilege> _DESERIALIZER = new StringEnum.Deserializer<>(
			IndexPrivilege.values());
}

==> elasticsearch-java-7.16.0-sources.jar: co/elastic/clients/elasticsearch/security/IndexPrivilege.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.security;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/security/_types/Privileges.ts#L102-L121">API
 *      specification</a>
 */
@JsonpDeserializable
public enum IndexPrivilege implements JsonEnum {
	All("all"),

	AutoConfigure("auto_configure"),

	Create("create"),

	CreateDoc("create_doc"),

	CreateIndex("create_index"),

	Delete("delete"),

	DeleteIndex("delete_index"),

	Index("index"),

	Maintenance("maintenance"),

	Manage("manage"),

	ManageFollowIndex("manage_follow_index"),

	ManageIlm("manage_ilm"),

	ManageLeaderIndex("manage_leader_index"),

	Monitor("monitor"),

	Read("read"),

	ReadCrossCluster("read_cross_cluster"),

	ViewIndexMetadata("view_index_metadata"),

	Write("write"),

	;

	private final String jsonValue;

	IndexPrivilege(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<IndexPrivilege> _DESERIALIZER = new JsonEnum.Deserializer<>(
			IndexPrivilege.values());
}
